@@ -122,6 +122,10 @@ class MySQL(Dialect):
 
         KEYWORDS = {
             **tokens.Tokenizer.KEYWORDS,
+            "MEDIUMTEXT": TokenType.MEDIUMTEXT,
+            "LONGTEXT": TokenType.LONGTEXT,
+            "MEDIUMBLOB": TokenType.MEDIUMBLOB,
+            "LONGBLOB": TokenType.LONGBLOB,
             "START": TokenType.BEGIN,
             "SEPARATOR": TokenType.SEPARATOR,
             "_ARMSCII8": TokenType.INTRODUCER,
@@ -454,6 +458,12 @@ class MySQL(Dialect):
             exp.LikeProperty,
         }
 
+        TYPE_MAPPING = generator.Generator.TYPE_MAPPING.copy()
+        TYPE_MAPPING.pop(exp.DataType.Type.MEDIUMTEXT)
+        TYPE_MAPPING.pop(exp.DataType.Type.LONGTEXT)
+        TYPE_MAPPING.pop(exp.DataType.Type.MEDIUMBLOB)
+        TYPE_MAPPING.pop(exp.DataType.Type.LONGBLOB)
+
         WITH_PROPERTIES: t.Set[t.Type[exp.Property]] = set()
 
         def show_sql(self, expression):
